documentationtools.GraphvizSubgraph
===================================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph

.. autoclass:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.append
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.attributes
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.canonical_name
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.children
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.depth
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.depthwise_inventory
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.edge_attributes
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.edges
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.extend
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.graph_order
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.graphviz_format
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.improper_parentage
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.index
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.insert
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.is_cluster
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.is_digraph
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.leaves
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.name
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.node_attributes
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.nodes
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.parent
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.pop
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.proper_parentage
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.remove
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.root
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.unflattened_graphviz_format
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__contains__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__copy__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__deepcopy__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__delitem__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__eq__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__format__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__getitem__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__iter__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__len__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__ne__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__repr__
      ~abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__setitem__

Bases
-----

- :py:class:`documentationtools.GraphvizGraph <abjad.tools.documentationtools.GraphvizGraph.GraphvizGraph>`

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode>`

- :py:class:`documentationtools.GraphvizObject <abjad.tools.documentationtools.GraphvizObject.GraphvizObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.canonical_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.edge_attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.edges
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.node_attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.unflattened_graphviz_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.is_cluster
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.is_digraph
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizSubgraph.GraphvizSubgraph.__setitem__
   :noindex:
